package stronglogic.cointrx;

import android.app.Fragment;
import android.app.FragmentManager;
import android.app.FragmentTransaction;
import android.net.Uri;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.design.widget.BottomNavigationView;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;

import stronglogic.cointrx.fragment.LoginFragment;
import stronglogic.cointrx.fragment.MediaFragment;

public class MainActivity extends AppCompatActivity implements LoginFragment.loginListen, MediaFragment.MediaListen {

    private static final String TAG = "TRX_MAIN";

    private static final int MediaFragmentClass = 31;
    private static final int LoginFragmentClass = 32;

    private TextView mTextMessage;

    public enum mainFragments { LOGIN, MEDIA }

    private mainFragments activeFragment;

    private HashMap<String, Integer> fragmentClassMap = createFragClassMap();

    private static HashMap<String, Integer> createFragClassMap() {
        HashMap<String, Integer> map = new HashMap<>();
        map.put(MediaFragment.class.toString(), MediaFragmentClass);
        map.put(LoginFragment.class.toString(), LoginFragmentClass);

        return map;
    }



    private BottomNavigationView.OnNavigationItemSelectedListener mOnNavigationItemSelectedListener
            = new BottomNavigationView.OnNavigationItemSelectedListener() {

        @Override
        public boolean onNavigationItemSelected(@NonNull MenuItem item) {
            return false;
        }

    };

    private void startActiveFragment(Fragment fragment) {

        Class fragmentClass;

        ArrayList<Class> fragmentClasses = new ArrayList<Class>(Arrays.asList(
                MediaFragment.class,
                LoginFragment.class
        ));

         if ((fragmentClass = findFragment(fragmentClasses, fragment)) != null) {
             switch (fragmentClassMap.get(fragmentClass.toString())) {

                 case MediaFragmentClass:
                     if (activateFragment(fragment, R.id.activeFragment)) {
                         this.activeFragment = mainFragments.MEDIA;
                     }
                     break;

                 case LoginFragmentClass:
                     if (activateFragment(fragment, R.id.activeFragment)) {
                         this.activeFragment = mainFragments.LOGIN;
                     }
                     break;
             }
         }
    }

    private boolean activateFragment(Fragment fragment, int fragmentId) {
        try {
            FragmentManager fm = getFragmentManager();
            FragmentTransaction ft = fm.beginTransaction();

            if (fm.findFragmentById(fragmentId) != null) {
                ft.replace(fragmentId, fragment);
            } else {
                ft.add(fragmentId, fragment);
            }
            ft.addToBackStack(null);
            ft.commit();

            return true;
        } catch (Exception e) {
            e.printStackTrace();
            Log.e(TAG, e.getMessage());
        }

        return false;
    }

    private Class findFragment(ArrayList<Class> classList, Fragment fragment) {
        Class fragClass = fragment.getClass();
        Class returnClass = null;
        for (Class objClass : classList) {
            if (fragClass == objClass) {
                returnClass = objClass;
            }
        }
        return returnClass;
    }


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        Toolbar mToolbar = (Toolbar) findViewById(R.id.app_bar);

        mToolbar.setTitleTextColor(ContextCompat.getColor(this, R.color.colorAccent));

        setSupportActionBar(mToolbar);

        mTextMessage = (TextView) findViewById(R.id.message);
        BottomNavigationView navigation = (BottomNavigationView) findViewById(R.id.navigation);
        navigation.setOnNavigationItemSelectedListener(mOnNavigationItemSelectedListener);

        mediaFeed();
    }


    /**
     * Methods for calling Fragments
     **/

    private void mediaFeed() {
        startActiveFragment(MediaFragment.newInstance("Test 3", "Test 4"));
    }

    private void loginStart() {
        startActiveFragment(LoginFragment.newInstance("Test 1", "Test2"));
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(R.menu.navigation, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.navigation_home:
                mTextMessage.setText(R.string.title_home);
                return true;
            case R.id.navigation_dashboard:
                mTextMessage.setText(R.string.title_dashboard);
                return true;
            case R.id.navigation_login:

                mTextMessage.setText(R.string.title_notifications);

                loginStart();

                return true;
        }
        return super.onOptionsItemSelected(item);
    }

    /****
     ** Fragment Listeners **
     ****/

    @Override
    public void onLoginInteraction(Uri uri) {

    }

    @Override
    public void onMediaInteraction(Uri uri) {

    }
}
